@@ -113,6 +113,7 @@ socket: %s`, socket)), 0600)
 		"policy applied":              {args: []string{"policy", "applied"}},
 		"policy debug gpolist-script": {args: []string{"policy", "debug", "gpolist-script"}},
 		"policy update":               {args: []string{"policy", "update"}},
+		"policy purge":                {args: []string{"policy", "purge"}},
 		"service cat":                 {args: []string{"service", "cat"}},
 		"service status":              {args: []string{"service", "status"}},
 		"service stop":                {args: []string{"service", "stop"}},
@@ -190,9 +191,6 @@ client_timeout: %d`, socket, tc.timeout)), 0600)
 	}
 }
 
-// createConf generates an adsys configuration in a temporary directory
-// It will use adsysDir for socket, cache and run dir if provided.
-
 // Option represents an optional function to change the winbind backend.
 type confOption func(*confOptions)
 
@@ -213,6 +211,8 @@ func confWithBackend(backend string) confOption {
 	}
 }
 
+// createConf generates an adsys configuration in a temporary directory
+// It will use adsysDir for socket, cache and run dir if provided.
 func createConf(t *testing.T, opts ...confOption) (conf string) {
 	t.Helper()
 
@@ -229,13 +229,14 @@ func createConf(t *testing.T, opts ...confOption) (conf string) {
 
 	// Create config
 	confFile := filepath.Join(args.adsysDir, "adsys.yaml")
-	err := os.WriteFile(confFile, []byte(fmt.Sprintf(`
+	confData := []byte(fmt.Sprintf(`
 # Service and client configuration
 verbose: 2
 socket: %s/socket
 
 # Service only configuration
 cache_dir: %s/cache
+state_dir: %s/lib
 run_dir: %s/run
 service_timeout: 30
 
@@ -254,9 +255,10 @@ policykit_dir: %s/polkit-1
 apparmor_dir: %s/apparmor.d/adsys
 apparmorfs_dir: %s/apparmorfs
 systemunit_dir: %s/systemd/system
-`, args.adsysDir, args.adsysDir, args.adsysDir, args.backend, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir)), 0600)
-	require.NoError(t, err, "Setup: config file should be created")
+global_trust_dir: %s/share/ca-certificates
+`, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.backend, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir, args.adsysDir))
 
+	testutils.WriteFile(t, confFile, confData, os.ModePerm)
 	require.NoError(t, os.MkdirAll(filepath.Join(args.adsysDir, "dconf"), 0750), "Setup: should create dconf dir")
 	// Don’t create empty dirs for sudo and polkit: todo: same for dconf?
 
