@@ -41,6 +41,13 @@ const (
 	UserObject ObjectClass = "user"
 	// ComputerObject is a computer representation in AD.
 	ComputerObject ObjectClass = "computer"
+
+	// certAutoEnrollKey is the GPO entry that configures certificate autoenrollment.
+	certAutoEnrollKey string = "Software/Policies/Microsoft/Cryptography/AutoEnrollment/AEPolicy"
+
+	// policyServerPrefix is the GPO prefix containing keys that configure
+	// policy servers for certificate enrollment.
+	policyServersPrefix string = "Software/Policies/Microsoft/Cryptography/PolicyServers/"
 )
 
 type gpo downloadable
@@ -132,7 +139,7 @@ func New(ctx context.Context, configBackend backends.Backend, hostname string, o
 	}
 
 	krb5CacheDir := filepath.Join(args.runDir, "krb5cc")
-	if err := os.MkdirAll(krb5CacheDir, 0700); err != nil {
+	if err := os.MkdirAll(filepath.Join(krb5CacheDir, "tracking"), 0700); err != nil {
 		return nil, err
 	}
 	sysvolCacheDir := filepath.Join(args.cacheDir, "sysvol")
@@ -181,10 +188,12 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 		return pols, fmt.Errorf(i18n.G("user name %q should be of the form %s@DOMAIN"), objectName, objectName)
 	}
 
-	krb5CCPath := filepath.Join(ad.krb5CacheDir, objectName)
 	if objectClass == ComputerObject && objectName != ad.hostname {
 		return pols, fmt.Errorf(i18n.G("requested a type computer of %q which isn't current host %q"), objectName, ad.hostname)
 	}
+
+	krb5CCPath := filepath.Join(ad.krb5CacheDir, objectName)
+	krb5CCSymlink := filepath.Join(ad.krb5CacheDir, "tracking", objectName)
 	// Create a ccache symlink on first fetch for future calls (on refresh for instance)
 	if userKrb5CCName != "" || objectClass == ComputerObject {
 		src := userKrb5CCName
@@ -195,11 +204,18 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 				return pols, err
 			}
 		}
-		if err := ad.ensureKrb5CCName(src, krb5CCPath); err != nil {
+
+		// Create a symlink to the ccache file
+		if err := ad.ensureKrb5CCSymlink(src, krb5CCSymlink); err != nil {
 			return pols, err
 		}
 	}
 
+	// Ensure we have an up-to-date copy of the ccache file
+	if err := ad.ensureKrb5CCCopy(krb5CCSymlink, krb5CCPath); err != nil {
+		return pols, err
+	}
+
 	var online bool
 	if online, err = ad.configBackend.IsOnline(); err != nil {
 		return pols, err
@@ -328,39 +344,51 @@ func (ad *AD) GetPolicies(ctx context.Context, objectName string, objectClass Ob
 	return policies.New(ctx, gposRules, assetsDbPath)
 }
 
-// ListActiveUsers return the list of active users on the system.
-func (ad *AD) ListActiveUsers(ctx context.Context) (users []string, err error) {
+// ListUsers returns the list of users on the system based on their cached policy information.
+// If active is true, the list of users is retrieved from the cached Kerberos ticket information.
+func (ad *AD) ListUsers(ctx context.Context, active bool) (users []string, err error) {
 	defer decorate.OnError(&err, i18n.G("can't list users from cache"))
 
-	log.Debug(ctx, "ListActiveUsers")
+	log.Debug(ctx, "ListUsers")
 
 	ad.Lock()
 	defer ad.Unlock()
 
-	files, err := os.ReadDir(ad.krb5CacheDir)
+	cacheDir := ad.policiesCacheDir
+	if active {
+		cacheDir = filepath.Join(ad.krb5CacheDir, "tracking")
+	}
+
+	entries, err := os.ReadDir(cacheDir)
 	if err != nil {
 		return users, fmt.Errorf(i18n.G("failed to read cache directory: %v"), err)
 	}
 
-	for _, file := range files {
-		if !strings.Contains(file.Name(), "@") {
+	for _, entry := range entries {
+		if !strings.Contains(entry.Name(), "@") {
 			continue
 		}
-		users = append(users, file.Name())
+
+		// Silently skip over dangling symlinks
+		if active {
+			if _, err := os.Stat(filepath.Join(cacheDir, entry.Name())); err != nil && errors.Is(err, fs.ErrNotExist) {
+				continue
+			}
+		}
+		users = append(users, entry.Name())
 	}
 	return users, nil
 }
 
-// ensureKrb5CCName manages user ccname symlinks.
-// It handles concurrent calls, and only recreate the symlink if we want to point to
-// a new destination.
-func (ad *AD) ensureKrb5CCName(srcKrb5CCName, dstKrb5CCName string) (err error) {
-	defer decorate.OnError(&err, i18n.G("can't create symlink for caching"))
-
+// ensureKrb5CCSymlink manages user ccname ticket symlinks.
+// It handles concurrent calls, and works by creating a symlink to the
+// actual ticket for tracking purposes.
+// It only recreates the symlink if we want to point to a new destination.
+func (ad *AD) ensureKrb5CCSymlink(srcKrb5CCName, dstKrb5CCName string) error {
 	ad.Lock()
 	defer ad.Unlock()
 
-	srcKrb5CCName, err = filepath.Abs(srcKrb5CCName)
+	srcKrb5CCName, err := filepath.Abs(srcKrb5CCName)
 	if err != nil {
 		return fmt.Errorf(i18n.G("can't get absolute path of ccname to symlink to: %v"), err)
 	}
@@ -377,12 +405,69 @@ func (ad *AD) ensureKrb5CCName(srcKrb5CCName, dstKrb5CCName string) (err error)
 		}
 	}
 
+	if err := os.MkdirAll(filepath.Dir(dstKrb5CCName), 0700); err != nil {
+		return fmt.Errorf(i18n.G("failed to create parent directory for symlink: %w"), err)
+	}
+
 	if err := os.Symlink(srcKrb5CCName, dstKrb5CCName); err != nil {
 		return err
 	}
 	return nil
 }
 
+// ensureKrb5CCCopy checks if the cached krb5cc ticket is up to date and updates
+// it if not.
+// The file ownership is changed to the calling user (root) in order to satisfy
+// the Heimdal implementation of Kerberos.
+// To track modifications to the krb5cc file we look at the mtime of the
+// original ticket and keep it up to date with
+// the copy.
+func (ad *AD) ensureKrb5CCCopy(krb5CCSymlink, krb5CCCopyName string) error {
+	ad.Lock()
+	defer ad.Unlock()
+
+	krb5CCSrc, err := os.Readlink(krb5CCSymlink)
+	if err != nil {
+		return fmt.Errorf(i18n.G("failed to read krb5cc symlink: %w"), err)
+	}
+
+	if copyStat, err := os.Lstat(krb5CCCopyName); err == nil && copyStat.Mode()&os.ModeSymlink == 0 {
+		// We already have a copy of the ticket, let's check if we need to update it
+		srcStat, err := os.Stat(krb5CCSrc)
+		if err != nil {
+			return fmt.Errorf(i18n.G("failed to stat source ticket: %w"), err)
+		}
+
+		// The source ticket is not newer than the destination one, no need to update
+		if !srcStat.ModTime().After(copyStat.ModTime()) {
+			return nil
+		}
+	}
+
+	// The ticket is either not present or outdated, let's update it
+	// Copy the ticket
+	if err := safeCopyFile(krb5CCSrc, krb5CCCopyName, 0600); err != nil {
+		return err
+	}
+
+	return nil
+}
+
+// safeCopyFile copies a file from src to dst, using the specified mode.
+// It first writes to a temporary file in the same directory as dst, then
+// renames it to dst, ensuring the write is atomic.
+func safeCopyFile(src, dst string, mode os.FileMode) error {
+	content, err := os.ReadFile(src)
+	if err != nil {
+		return fmt.Errorf(i18n.G("failed to read source file: %w"), err)
+	}
+	if err := os.WriteFile(dst+".new", content, mode); err != nil {
+		return err
+	}
+
+	return os.Rename(dst+".new", dst)
+}
+
 func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass) (r []policies.GPO, err error) {
 	keyFilterPrefix := fmt.Sprintf("%s/%s/", adcommon.KeyPrefix, consts.DistroID)
 
@@ -444,6 +529,16 @@ func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass
 			var currentKey string
 			var overrideEnabled bool
 			for _, pol := range pols {
+				// Rewrite the certificate autoenrollment key so we can easily
+				// use it in the policy manager
+				if pol.Key == certAutoEnrollKey {
+					pol.Key = fmt.Sprintf("%scertificate/autoenroll/all", keyFilterPrefix)
+				}
+
+				if strings.HasPrefix(pol.Key, policyServersPrefix) {
+					pol.Key = fmt.Sprintf("%scertificate/%s/all", keyFilterPrefix, pol.Key)
+				}
+
 				// Only consider supported policies for this distro
 				if !strings.HasPrefix(pol.Key, keyFilterPrefix) {
 					continue
